import java.net.*;
import java.io.*;
import java.util.*;

/**
 * Network Client - This is the client side of the network.
 * 
 * @author David Couvrette
 * May 30th 2007
 * CSE190L
 * 
 */

class NetworkClient implements Runnable{
  
  // connection to server
  private Socket socket;
  
  // reference to clients "mini" model
  private PongClientModel model;
  
  /**
   * Connects to a remote host given a host name.
   * Stores a reference to the client model
   * @param host The host you are connecting to.
   * @param model A reference to the clients version of the model
   */
  public NetworkClient(String host, PongClientModel model) {
    try {
      socket = new Socket(host, 500);
    } catch(Exception e) {
      System.out.println(e);
    }
    this.model = model;
    // gives the model a reference to this NetworkClient
    model.setNetwork(this);
  }
  
  /**
   * Waits for incoming messages from the server.
   * Assumes the server is sending PongModel objects.
   * When it receives a PongModel object, it forwards this to the client model,
   * then starts waiting again for another message.
   */
  public void run() {
    try {
      InputStream in = socket.getInputStream();
      while (true) {
        ObjectInputStream ois = new ObjectInputStream(in);
        PongModel model = (PongModel)ois.readObject();
        this.model.update(model);
      }
    } catch (Exception e) {
      System.out.println("Reading updated model from server: " + e);
    }
  }
  
  /**
   * Sends a message to the server to update where the rightPaddle is located
   * @param rightPaddle The paddle you want to send to the server
   */
  public void movePaddle(Paddle rightPaddle) {
    try {
      ObjectOutputStream oos = new ObjectOutputStream(socket.getOutputStream());
      oos.writeObject(rightPaddle);
      oos.flush();
    } catch (Exception e) {
      System.out.println("sending update right paddle message to server" + e);
    }
  }
}