import java.io.*;

/**
 * Paddle - This stores information about a paddle.
 * 
 * @author David Couvrette
 * May 30th 2007
 * CSE190L
 * 
 */

public class Paddle implements Serializable {
  
  // Used in AI, not when in Player vs. Player mode.
  public enum Direction { UP, DOWN, STOP }
  private Direction direction;
  
  // the y coordinate of the middle of the paddle
  private double y;
  // the height of the paddle
  private double height;
  
  /**
   * Initializes the paddle.
   * The y-coordinate can be changed, but the height is immutable
   * @param y This is the y-coordinate of the center of the paddle
   * @param height This is the height of the paddle
   */
  public Paddle(double y, double height) {
    direction = Direction.STOP;
    this.y = y;
    this.height = height;
  }
  
  /**
   * Sets the y coordinate of the paddle
   * @param y The new y coordinate of the paddle
   */
  public void setY(double y) {
    this.y = y;
  }
  
  /**
   * Sets the direction of the paddle (used for AI)
   * @param dir The new direction of the paddle
   */
  public void setDirection(Direction dir) {
    direction = dir;
  }
  
  /**
   * Gets the y coordinate.
   * @return The y coordinate of the paddle.
   */
  public double getY() {
    return y;
  }
  
  /**
   * Gets the height of the paddle.
   * @return The height of the paddle.
   */
  public double getHeight() {
    return height;
  }
  
  /**
   * Gets the direction of the paddle.
   * @return The direction of the paddle.
   */
  public Direction getDirection() {
    return direction;
  }
}