import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Client Controller - This is the controller / frame for the client.
 * 
 * @author David Couvrette
 * May 30th 2007
 * CSE190L
 * 
 */

public class PongClientController {
  private JFrame frame;
  private PongPanel panel;
  private PongClientModel model;
  
  /**
   * Initialize the controller/frame.
   * Adds mouse listener to panel
   * Adds connect button to frame
   * @param model a reference to the client model
   */
  public PongClientController(PongClientModel model) {
    this.model = model;
    frame = new JFrame();
    frame.setTitle("Pong - Client");
    frame.setSize(420, 465);
    frame.setResizable(false);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    panel = new PongPanel(model);
    model.addListener(panel);
    frame.add(panel, BorderLayout.CENTER);
    frame.add(startButton(), BorderLayout.SOUTH);
    panel.addMouseMotionListener(new MouseInputAdapter() {
      public void mouseMoved(MouseEvent e) {
        mouseMove(e);
      }
    });
    
    frame.setVisible(true);
  }
  
  /**
   * Notifies the client model that the mouse has moved
   * @param e The mouse event corresponding to where the mouse is
   */
  private void mouseMove(MouseEvent e) {
    model.mouseMoved(e.getPoint().getY());
  }
  
  /**
   * Creates a connect button.  Currently the address of the host is
   * hard coded.
   * @return The JPanel with the connect button.
   */
  private JPanel startButton() {
    JPanel p = new JPanel();
    JButton b = new JButton("Connect");
    b.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        model.connectGame("127.0.0.1");
      }
    });
    p.add(b);
    return p;
  }
}