import java.awt.*;
import java.util.*;
import java.awt.event.*;

/**
 * Client Model - Stores only the information neccesary to draw
 * the views.  Most of the game logic is done in PongModel.
 * 
 * @author David Couvrette
 * May 30th 2007
 * CSE190L
 * 
 */

public class PongClientModel implements Model {
  private Point ball;
  private double diameter;
  private Paddle leftPaddle;
  private Paddle rightPaddle;
  private NetworkClient client;
  
  private java.util.List<Listener> listeners;
  
  /**
   * Initialize the list of listeners
   */
  public PongClientModel() {
    listeners = new java.util.ArrayList<Listener>();
  }
  
  /**
   * Updates the client model with the given models data
   * @param model The model used to update this client model
   */
  public synchronized void update(PongModel model) {
      this.diameter = model.getDiameter();
      this.ball = model.getBall();
      this.leftPaddle = model.getLeftPaddle();
      this.rightPaddle = this.rightPaddle == null ? model.getRightPaddle() : this.rightPaddle;
      update();
  }
  
  /**
   * Add a listener to current set of listeners
   * @param listener Adds this listener to the model
   */
  public void addListener(Listener listener) {
    listeners.add(listener);
  }
  
  /**
   * Notifies all the listeners that an update has occured
   */
  private void update() {
    for (Listener listener : listeners) {
      listener.update();
    }
  }
  
  /**
   * Connects to a server with the given host name
   * @param host Name of host to connect to.
   */
  public void connectGame(String host) {
    Thread t = new Thread(new NetworkClient(host, this));
    t.start();
  }
  
  /**
   * Gets the left paddle.
   * @return The left paddle.
   */
  public synchronized Paddle getLeftPaddle() {
    return leftPaddle;
  }
  
  /**
   * Gets the right paddle.
   * @return The right paddle.
   */
  public synchronized Paddle getRightPaddle() {
    return rightPaddle;
  }
  
  /**
   * Gets the ball.
   * @return The ball.
   */
  public synchronized Point getBall() {
    return ball;
  }
  
  /**
   * Gets the diameter of the ball.
   * @return The diameter of the ball.
   */
  public synchronized double getDiameter() {
    return diameter;
  }
  
  /**
   * Stores the NetworkClient
   * @param The networkclient
   */
  public void setNetwork(NetworkClient client) {
    this.client = client;
  }
  
  /**
   * Updates the paddle location and notifies server of change
   * @param y New location of paddle
   */
  public synchronized void mouseMoved(double y) {
    if (client != null && rightPaddle != null) {
      rightPaddle.setY(y);
      client.movePaddle(rightPaddle);
      update();
    }
  }
}