import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Server Controller - This is the controller / frame for the Server.
 * 
 * @author David Couvrette
 * May 30th 2007
 * CSE190L
 * 
 */

public class PongController {
  private JFrame frame;
  private PongPanel panel;
  private PongModel model;
  
  /**
   * Initializes the controller/frame.
   * Adds panel, start button, and mousemotion listener
   * @param model A reference to the model
   */
  public PongController(PongModel model) {
    this.model = model;
    frame = new JFrame();
    frame.setTitle("Pong - Server");
    frame.setSize(420, 465);
    frame.setResizable(false);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    panel = new PongPanel(model);
    model.addListener(panel);
    frame.add(panel, BorderLayout.CENTER);
    frame.add(startButton(), BorderLayout.SOUTH);
    panel.addMouseMotionListener(new MouseInputAdapter() {
      public void mouseMoved(MouseEvent e) {
        mouseMove(e);
      }
    });
    
    frame.setVisible(true);
  }
  
  /**
   * Notifies the model of a mouse movement
   * @param e The mouseevent information
   */
  private void mouseMove(MouseEvent e) {
    model.mouseMoved(e.getPoint().getY());
  }
  
  /**
   * Creates a JPanel with the startbutton and actionlistener for the button.
   * @return A JPanel with a button
   */
  private JPanel startButton() {
    JPanel p = new JPanel();
    JButton b = new JButton("Start");
    b.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        model.startGame();
      }
    });
    p.add(b);
    return p;
  }
}