import javax.swing.*;
import java.awt.*;
import java.awt.geom.*;

/**
 * Panel - The view for both the client and server
 * 
 * @author David Couvrette
 * May 30th 2007
 * CSE190L
 * 
 */

public class PongPanel extends JPanel implements Listener {
  
  private Model model;
  
  /**
   * Initializes the view to black
   * @param model Stores a reference to the model
   */
  public PongPanel(Model model) {
    this.model = model;
    setBackground(Color.BLACK);
  }
  
  /**
   * Paints the game
   * @param g The graphics object to draw on
   */
  public void paintComponent(Graphics g) {
    super.paintComponent(g);
    Graphics2D g2 = (Graphics2D) g;
    
    // draw ball
    g2.setPaint(Color.GREEN);
    Point p = model.getBall();
    double diameter = model.getDiameter();
    if (p != null) {
      Ellipse2D ball = new Ellipse2D.Double(p.x - diameter / 2, p.y - diameter / 2, diameter, diameter);
      g2.fill(ball);
    }
    
    // draw paddles
    g2.setPaint(Color.RED);
    Paddle left = model.getLeftPaddle();
    Paddle right = model.getRightPaddle();
    // verify that the paddles have been created
    if (left != null && right != null) {
      Rectangle2D leftPaddle = new Rectangle2D.Double(0, left.getY() - left.getHeight() / 2, 10, left.getHeight());
      Rectangle2D rightPaddle = new Rectangle2D.Double(getWidth() - 10, right.getY() - right.getHeight() / 2, 10, right.getHeight());
      g2.fill(leftPaddle);
      g2.fill(rightPaddle);
    }
  }
  
  /**
   * Update the view
   */
  public void update() {
    repaint();
  }
}